import { Vector2 } from '@archilogic/space-graph-core';
export type DisplayMode = 'color' | 'text' | 'shape';
export interface Range {
    start: number | null;
    end: number | null;
}
export interface State {
    selectedAttributeIds: string[];
    valueRanges: Record<string, Range>;
    colors: Record<string, string>;
    startColors: Record<string, string>;
    endColors: Record<string, string>;
    opacities: Record<string, number>;
    displayModes: Record<string, DisplayMode>;
    textFormats: Record<string, string>;
    shapeRadiusRanges: Record<string, Range>;
    textSizes: Record<string, number>;
    opacityRanges: Record<string, Range>;
    nextColorIndex: number;
    hideDefaultRoomstamps: boolean;
}
export interface NodeReference {
    id: string;
    shortId: string;
    name: string;
    attributeValue: string | number | boolean;
    labelPosition: Vector2;
}
export declare const defaults: {
    readonly textSize: 32;
    readonly shapeRadius: {
        readonly start: 0.2;
        readonly end: 1;
    };
    readonly opacity: {
        readonly boolean: 0.4;
        readonly default: 1;
        readonly numeric: {
            readonly start: 0.2;
            readonly end: 1;
        };
    };
};
export declare const state: {
    selectedAttributeIds: string[];
    valueRanges: Record<string, Range>;
    colors: Record<string, string>;
    startColors: Record<string, string>;
    endColors: Record<string, string>;
    opacities: Record<string, number>;
    displayModes: Record<string, DisplayMode>;
    textFormats: Record<string, string>;
    shapeRadiusRanges: Record<string, Range>;
    textSizes: Record<string, number>;
    opacityRanges: Record<string, Range>;
    nextColorIndex: number;
    hideDefaultRoomstamps: boolean;
};
export declare function resetState(): void;
export declare function resetAttributeState(attributeId: string): void;
export declare function useCustomAttribute(attrId: string): {
    definition: any;
    displayMode: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<DisplayMode, DisplayMode>;
    isNumeric: import('../vue/dist/vue.esm-browser.prod.js').ComputedRef<boolean>;
    textSize: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    textFormat: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<string, string>;
    opacity: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    color: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<string, string>;
    startColor: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<string, string>;
    endColor: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<string, string>;
    nodes: import('../vue/dist/vue.esm-browser.prod.js').ComputedRef<NodeReference[]>;
    numericValueRange: import('../vue/dist/vue.esm-browser.prod.js').ComputedRef<{
        minValue: number;
        maxValue: number;
    }>;
    valueRangeStart: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    valueRangeEnd: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    opacityRangeStart: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    opacityRangeEnd: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    radiusRangeStart: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    radiusRangeEnd: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
};
